@@ -5,7 +5,7 @@ set -e
 VERSION=$(dpkg-parsechangelog | sed -ne 's,^Version: \(.*\)-.*,\1,p')
 SOURCE=$(dpkg-parsechangelog | sed -ne 's,Source: \(.*\),\1,p')
 
-SVNROOT=http://svn.apache.org/repos/asf/commons/sandbox/compress/trunk
+SVNROOT=http://svn.apache.org/repos/asf/commons/proper/compress/trunk
 SVNREVISION=$(echo $VERSION | sed -e 's,.*svn,,')
 
 DIR=$SOURCE
